@@ -77,6 +77,7 @@ public class CreateCDF implements CDFConstants{
              test     = Attribute.create(cdf, "Test", GLOBAL_SCOPE),
              testDate = Attribute.create(cdf, "TestDate", GLOBAL_SCOPE),
              ep16TestDate = Attribute.create(cdf, "epTestDate", GLOBAL_SCOPE),
+             utf8 = Attribute.create(cdf, "utf8", GLOBAL_SCOPE),
 
              validMin = Attribute.create(cdf, "VALIDMIN", VARIABLE_SCOPE),
              validMax = Attribute.create(cdf, "VALIDMAX", VARIABLE_SCOPE),
@@ -315,6 +316,9 @@ System.out.println("pad value="+longitude.getPadValue()+" status="+cdf.getStatus
           Entry.create(test,16,CDF_UINT1, new short[] {255,254});
           System.out.println("\tUINT1 completed.");
 
+          Entry.create(test,17,CDF_INT8, new Long(23456789010L));
+          System.out.println("\tINT8 completed.");
+
           double testDateData  = Epoch.compute(2002, 4, 25, 0, 0, 0, 0);
           Entry.create(testDate, 1, CDF_EPOCH, new Double(testDateData)); 
           System.out.println("\tEPOCH completed.");
@@ -330,6 +334,16 @@ System.out.println("pad value="+longitude.getPadValue()+" status="+cdf.getStatus
                        new Long(testTT2000));
           System.out.println("\tEPOCH completed.");
 
+          String spdf1 = new String("ASCII: ABCDEFG");
+          String spdf2 = new String("Latin1: ©æêü÷Æ¼®¢¥");
+          String spdf3 = new String("Chinese: 社安");
+          String spdf4 = new String("Other: ႡႢႣႤႥႦ");
+          Entry.create(utf8, 0, CDF_CHAR, spdf1);
+          Entry.create(utf8, 1, CDF_CHAR, spdf2);
+          Entry.create(utf8, 2, CDF_CHAR, spdf3);
+          Entry.create(utf8, 3, CDF_CHAR, spdf4);
+          System.out.println("\tUTF8 completed.");
+
           /************************************/
           /*  Add variable attribute entries  */
           /************************************/
@@ -366,6 +380,10 @@ System.out.println("pad value="+longitude.getPadValue()+" status="+cdf.getStatus
           tt2000.putEntry(dummy,  CDF_TIME_TT2000, new Long(testDateData2));
           System.out.println("\tAdded dummy for tt2000.");
 
+          newI8.putEntry(validMin, CDF_INT8, new Long(-12345678900L));
+          newI8.putEntry(validMax, CDF_INT8, new Long(12345678900L));
+          System.out.println("\tAdded VALIDMAX/VALIBMIN entries for newI8.");
+
           char ch = 'a'; 
           String myStr = String.valueOf(ch); 
           longitude.putEntry(myAttr,  CDF_CHAR, myStr);
